==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Символ À',
	'barre_adresse' => 'Адрес ',
	'barre_aide' => 'Используйте spip коды для форматирования текста',
	'barre_alignerdroite' => 'Абзац [/По правому краю /]',
	'barre_ancres' => 'Ссылки',
	'barre_barre' => 'Перечеркнуть',
	'barre_bulle' => 'Помощь',
	'barre_c_cedille_maj' => 'Символ Ç',
	'barre_cadre' => 'Выделить &lt;cadre&gt;текст&lt;/cadre&gt;',
	'barre_caracteres' => 'Специальные символы',
	'barre_centrer' => '[|Центрировать|] абзац',
	'barre_chercher' => 'Найти и заменить',
	'barre_clean' => 'Удалить HTML теги из кода',
	'barre_code' => 'Редактировать &lt;code&gt; текст &lt;/code&gt;',
	'barre_desindenter' => 'Убрать отступ',
	'barre_e_accent_aigu' => 'Символ É',
	'barre_e_accent_grave' => 'Символ È',
	'barre_ea' => 'Символ æ',
	'barre_ea_maj' => 'Символ Æ',
	'barre_encadrer' => '[(Выделить)] абзац',
	'barre_eo' => 'Символ œ',
	'barre_eo_maj' => 'Символ Œ',
	'barre_euro' => 'Символ €',
	'barre_exposant' => 'Форматировать &lt;sup&gt;  текст (суперскрипт) t&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Специальное форматирование',
	'barre_galerie' => 'Открыть изображения',
	'barre_gestion_anc_bulle' => 'Помощь',
	'barre_gestion_anc_caption' => 'Ссылки',
	'barre_gestion_anc_cible' => 'Ссылка откроется',
	'barre_gestion_anc_inserer' => 'Сделать ссылкой',
	'barre_gestion_anc_nom' => 'Текст ссылки',
	'barre_gestion_anc_pointer' => 'Указатель на ссылку',
	'barre_gestion_caption' => 'Условные обозначения',
	'barre_gestion_colonne' => 'Кол. колонок',
	'barre_gestion_cr_casse' => 'Учитывать регистр',
	'barre_gestion_cr_changercasse' => 'Изменить регистр',
	'barre_gestion_cr_changercassemajuscules' => 'Сделать ПРОПИСНЫМИ',
	'barre_gestion_cr_changercasseminuscules' => 'Сделать строчными',
	'barre_gestion_cr_chercher' => 'Поиск',
	'barre_gestion_cr_entier' => 'Только слова полностью',
	'barre_gestion_cr_remplacer' => 'Заменить',
	'barre_gestion_cr_tout' => 'Заменить все',
	'barre_gestion_entete' => 'Заголовок',
	'barre_gestion_ligne' => 'Кол. строк',
	'barre_gestion_taille' => 'Фиксированный размер',
	'barre_glossaire' => '[?glossaire] ссылка (Wikipedia)',
	'barre_gras' => '{{Полужирный}}',
	'barre_guillemets' => 'Выделить « двойными кавычками »',
	'barre_guillemets_simples' => 'Вставить между “кавычками”',
	'barre_indenter' => 'Добавить отступ',
	'barre_inserer_cadre' => 'Вставить форматированный текст (cadre)',
	'barre_inserer_caracteres' => 'Вставить специальные символы',
	'barre_inserer_code' => 'Выделение для программного кода (code)',
	'barre_intertitre' => '{{{Подзаголовок}}}',
	'barre_italic' => '{Курсив}',
	'barre_langue' => 'Аббревиатуры',
	'barre_lien' => 'Сделать [ссылкой->http://...]',
	'barre_lien_externe' => 'Внешняя ссылка',
	'barre_lien_input' => 'Укажите адрес для этой ссылки ( вы можете указать в формате URL http://www.monsite.com или просто написать номер статьи).',
	'barre_liste_ol' => 'Нумерованный список',
	'barre_liste_ul' => 'Список',
	'barre_lorem_ipsum' => 'Вставить пустой абзац',
	'barre_lorem_ipsum_3' => 'Вставить три пустых абзаца',
	'barre_miseenevidence' => '[*Подсветить*] текст',
	'barre_note' => 'Сделать [[сноску]]',
	'barre_paragraphe' => 'Создать абзац',
	'barre_petitescapitales' => 'Написать &lt;sc&gt;строчными &lt;/sc&gt;',
	'barre_poesie' => 'Форматирование для &lt;poesie&gt;поэзии&lt;/poesie&gt;',
	'barre_preview' => 'Пред.просмотр',
	'barre_quote' => '<quote>Цитата</quote>',
	'barre_stats' => 'Статистика',
	'barre_tableau' => 'Добавить или редактировать выбранную таблицу',

	// C
	'config_info_enregistree' => 'Настройки сохранены',

	// E
	'editer' => 'Редактировать',
	'explication_barre_outils_public' => 'Файлы CSS и Javascript для панели инструментов (extension Porte Plume) будут загружены на сайте и панель форматирования текста будет выводится в модуле комментариев, на форумах и в других местах редактирования текста на фронтэнде сайта, если это разрешено их конфигурацией. ',
	'explication_barre_outils_public_2' => 'Чтобы максимально облегчить сайт и ускорить время его загрузки, вы можете отключить добавление этих файлов. Тогда пользователи не смогут форматировать текст при добавлении комментариев и в других модулях.',

	// I
	'info_barre_outils_public' => 'Панель инструментов на сайте',
	'info_porte_plume_titre' => 'Настройка панели инструментов',

	// L
	'label_barre_outils_public_non' => 'Не добавлять скрипты панели инструментов на фронтэнд сайта',
	'label_barre_outils_public_oui' => 'Добавить скрипты для панели инструментов на фрондэнд сайта',

	// V
	'voir' => 'Пред.просмотр'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// B
	'barre_a_accent_grave' => 'Символ À',
	'barre_adresse' => 'Адрес ',
	'barre_aide' => 'Используйте spip коды для форматирования текста',
	'barre_alignerdroite' => 'Абзац [/По правому краю /]',
	'barre_ancres' => 'Ссылки',
	'barre_barre' => 'Перечеркнуть',
	'barre_bulle' => 'Помощь',
	'barre_c_cedille_maj' => 'Символ Ç',
	'barre_cadre' => 'Выделить &lt;cadre&gt;текст&lt;/cadre&gt;',
	'barre_caracteres' => 'Специальные символы',
	'barre_centrer' => '[|Центрировать|] абзац',
	'barre_chercher' => 'Найти и заменить',
	'barre_clean' => 'Удалить HTML теги из кода',
	'barre_code' => 'Редактировать &lt;code&gt; текст &lt;/code&gt;',
	'barre_desindenter' => 'Убрать отступ',
	'barre_e_accent_aigu' => 'Символ É',
	'barre_e_accent_grave' => 'Символ È',
	'barre_ea' => 'Символ æ',
	'barre_ea_maj' => 'Символ Æ',
	'barre_encadrer' => '[(Выделить)] абзац',
	'barre_eo' => 'Символ œ',
	'barre_eo_maj' => 'Символ Œ',
	'barre_euro' => 'Символ €',
	'barre_exposant' => 'Форматировать &lt;sup&gt;  текст (суперскрипт) t&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Специальное форматирование',
	'barre_galerie' => 'Открыть изображения',
	'barre_gestion_anc_bulle' => 'Помощь',
	'barre_gestion_anc_caption' => 'Ссылки',
	'barre_gestion_anc_cible' => 'Ссылка откроется',
	'barre_gestion_anc_inserer' => 'Сделать ссылкой',
	'barre_gestion_anc_nom' => 'Текст ссылки',
	'barre_gestion_anc_pointer' => 'Указатель на ссылку',
	'barre_gestion_caption' => 'Условные обозначения',
	'barre_gestion_colonne' => 'Кол. колонок',
	'barre_gestion_cr_casse' => 'Учитывать регистр',
	'barre_gestion_cr_changercasse' => 'Изменить регистр',
	'barre_gestion_cr_changercassemajuscules' => 'Сделать ПРОПИСНЫМИ',
	'barre_gestion_cr_changercasseminuscules' => 'Сделать строчными',
	'barre_gestion_cr_chercher' => 'Поиск',
	'barre_gestion_cr_entier' => 'Только слова полностью',
	'barre_gestion_cr_remplacer' => 'Заменить',
	'barre_gestion_cr_tout' => 'Заменить все',
	'barre_gestion_entete' => 'Заголовок',
	'barre_gestion_ligne' => 'Кол. строк',
	'barre_gestion_taille' => 'Фиксированный размер',
	'barre_glossaire' => '[?glossaire] ссылка (Wikipedia)',
	'barre_gras' => '{{Полужирный}}',
	'barre_guillemets' => 'Выделить « двойными кавычками »',
	'barre_guillemets_simples' => 'Вставить между “кавычками”',
	'barre_indenter' => 'Добавить отступ',
	'barre_inserer_cadre' => 'Вставить форматированный текст (cadre)', # MODIF
	'barre_inserer_caracteres' => 'Вставить специальные символы',
	'barre_inserer_code' => 'Выделение для программного кода (code)', # MODIF
	'barre_intertitre' => '{{{Подзаголовок}}}',
	'barre_italic' => '{Курсив}',
	'barre_langue' => 'Аббревиатуры',
	'barre_lien' => 'Сделать [ссылкой->http://...]',
	'barre_lien_externe' => 'Внешняя ссылка',
	'barre_lien_input' => 'Укажите адрес для этой ссылки ( вы можете указать в формате URL http://www.monsite.com или просто написать номер статьи).',
	'barre_liste_ol' => 'Нумерованный список',
	'barre_liste_ul' => 'Список',
	'barre_lorem_ipsum' => 'Вставить пустой абзац',
	'barre_lorem_ipsum_3' => 'Вставить три пустых абзаца',
	'barre_miseenevidence' => '[*Подсветить*] текст',
	'barre_note' => 'Сделать [[сноску]]',
	'barre_paragraphe' => 'Создать абзац',
	'barre_petitescapitales' => 'Написать &lt;sc&gt;строчными &lt;/sc&gt;',
	'barre_poesie' => 'Форматирование для &lt;poesie&gt;поэзии&lt;/poesie&gt;',
	'barre_preview' => 'Пред.просмотр',
	'barre_quote' => '<quote>Цитата</quote>',
	'barre_stats' => 'Статистика',
	'barre_tableau' => 'Добавить или редактировать выбранную таблицу',

	// C
	'config_info_enregistree' => 'Настройки сохранены',

	// E
	'editer' => 'Редактировать',
	'explication_barre_outils_public' => 'Файлы CSS и Javascript для панели инструментов (extension Porte Plume) будут загружены на сайте и панель форматирования текста будет выводится в модуле комментариев, на форумах и в других местах редактирования текста на фронтэнде сайта, если это разрешено их конфигурацией. ',
	'explication_barre_outils_public_2' => 'Чтобы максимально облегчить сайт и ускорить время его загрузки, вы можете отключить добавление этих файлов. Тогда пользователи не смогут форматировать текст при добавлении комментариев и в других модулях.',

	// I
	'info_barre_outils_public' => 'Панель инструментов на сайте',
	'info_porte_plume_titre' => 'Настройка панели инструментов',

	// L
	'label_barre_outils_public_non' => 'Не добавлять скрипты панели инструментов на фронтэнд сайта',
	'label_barre_outils_public_oui' => 'Добавить скрипты для панели инструментов на фрондэнд сайта',

	// V
	'voir' => 'Пред.просмотр',
];
